matd_print_transpose

Function matd_print_transpose 

pub unsafe extern "C" fn matd_print_transpose(
    m: *const matd_t,
    fmt: *const c_char,
)
Prints the transpose of the supplied matrix ‘m’ to standard output by applying the supplied printf format specifier ‘fmt’ for each individual element. Each row will be printed on a separate newline.