apriltag_pose_t

Struct apriltag_pose_t 

#[repr(C)]
pub struct apriltag_pose_t { pub R: *mut matd_t, pub t: *mut matd_t, }
This struct holds the transformation from the camera optical frame to the April tag frame. The pose refers to the position of the tag within the camera frame.

Fields

R: *mut matd_tt: *mut matd_t