Function apriltag_sys::matd_print
source · pub unsafe extern "C" fn matd_print(
m: *const matd_t,
fmt: *const c_char
)Expand description
Prints the supplied matrix ‘m’ to standard output by applying the supplied printf format specifier ‘fmt’ for each individual element. Each row will be printed on a separate newline.