#[repr(C)]pub struct apriltag_pose_t {
pub R: *mut matd_t,
pub t: *mut matd_t,
}Expand description
This struct holds the transformation from the camera optical frame to the April tag frame. The pose refers to the position of the tag within the camera frame.
Fields
R: *mut matd_tt: *mut matd_tTrait Implementations
Sourceimpl Clone for apriltag_pose_t
impl Clone for apriltag_pose_t
Sourcefn clone(&self) -> apriltag_pose_t
fn clone(&self) -> apriltag_pose_t
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for apriltag_pose_t
impl Debug for apriltag_pose_t
impl Copy for apriltag_pose_t